@@ -1484,19 +1484,8 @@ get_next_duplicate_name (char *name, int count_increment)
 
 	unescaped_name = g_filename_to_utf8 (unescaped_tmp_name, -1,
 					     NULL, NULL, NULL);
-	if (!unescaped_name) {
-		/* Couldn't convert to utf8 - probably
-		 * G_BROKEN_FILENAMES not set when it should be.
-		 * Try converting from the locale */
-		unescaped_name = g_locale_to_utf8 (unescaped_tmp_name, -1, NULL, NULL, NULL);	
-
-		if (!unescaped_name) {
-			unescaped_name = eel_make_valid_utf8 (unescaped_tmp_name);
-		}
-	}
-		
 	g_free (unescaped_tmp_name);
-	
+
 	unescaped_result = get_duplicate_name (unescaped_name, count_increment);
 	g_free (unescaped_name);
 
