@@ -30,6 +30,7 @@
 
 
 #include "file-manager/fm-bonobo-provider.h"
+#include "file-manager/fm-ditem-page.h"
 #include "file-manager/fm-desktop-icon-view.h"
 #include "file-manager/fm-icon-view.h"
 #include "file-manager/fm-list-view.h"
@@ -404,6 +405,7 @@ finish_startup (NautilusApplication *application)
 	nautilus_module_init ();
 
 	nautilus_module_add_type (FM_TYPE_BONOBO_PROVIDER);
+	nautilus_module_add_type (FM_TYPE_DITEM_PAGE);
 	
 	/* initialize the sound machinery */
 	nautilus_sound_init ();
@@ -920,6 +922,25 @@ nautilus_application_close_parent_windows (NautilusSpatialWindow *window)
 	}
 }
 
+void
+nautilus_application_close_all_spatial_windows (void)
+{
+	GList *list_copy;
+	GList *l;
+	
+	list_copy = g_list_copy (nautilus_application_spatial_window_list);
+	for (l = list_copy; l != NULL; l = l->next) {
+		NautilusWindow *window;
+		
+		window = NAUTILUS_WINDOW (l->data);
+		
+		if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
+			nautilus_window_close (window);
+		}
+	}
+	g_list_free (list_copy);
+}
+
 static void
 nautilus_application_destroyed_window (GtkObject *object, NautilusApplication *application)
 {
