@@ -879,12 +879,8 @@ add_view_as_bonobo_menu_item (NautilusWindow *window,
 		 identifier->view_as_label_with_mnemonic,
 		 "viewers group");
 
-	tip = NULL;
-	if (identifier->viewer_label != NULL) {
-		tip = g_strdup_printf (_("Display this location with \"%s\""),
-				       identifier->viewer_label);
-	}
-
+	tip = g_strdup_printf (_("Display this location with \"%s\""),
+			       identifier->viewer_label);
 	item_path = nautilus_bonobo_get_numbered_menu_item_path
 		(window->details->shell_ui, 
 		 placeholder_path, 
@@ -1144,11 +1140,28 @@ static char *
 compute_default_title (const char *text_uri)
 {
 	NautilusFile *file;
-	char *title;
+	GnomeVFSURI *uri;
+	char *title, *displayname;
+	const char *hostname;
+
+	hostname = NULL;
 
 	if (text_uri) {
 		file = nautilus_file_get (text_uri);
-		title = nautilus_file_get_display_name (file);
+		uri = gnome_vfs_uri_new (text_uri);
+		if (uri && !gnome_vfs_uri_is_local (uri)) {
+			hostname = gnome_vfs_uri_get_host_name (uri);
+		}
+		displayname = nautilus_file_get_display_name (file);
+		if (hostname) {
+			title = g_strdup_printf (_("%s on %s"), displayname, hostname);
+			g_free (displayname);
+		} else {
+			title = displayname;
+		}
+		if (uri) {
+			gnome_vfs_uri_unref (uri);
+		}
 		nautilus_file_unref (file);
 	} else {
 		title = g_strdup ("");
